@@ -50,6 +50,13 @@ A10_GLOBAL_OPTS = [
                 help=_('Use shared for template')),
     cfg.StrOpt('default_flavor_id', default=None,
                help=_('Default flavor ID to apply globally to all users')),
+    cfg.BoolOpt('handle_vrid', default=True,
+                help=_('Deletes floating ip when True.')),
+    cfg.BoolOpt('validate_subnet', default=True,
+               help=_('Allow for members and VIPs to exist in the same '
+                      ' subnet (for use with kube cloud provider)')),
+    cfg.BoolOpt('nlbaas_member_names', default=False,
+                help=_('Use neutron lbaas member names in a10 config.')),
 ]
 
 A10_VTHUNDER_OPTS = [
