@@ -99,13 +99,13 @@ class LoadBalancerFlows(object):
         vthunder = self._vthunder_repo.get_vthunder_by_project_id(db_apis.get_session(),
                                                                   project_id)
 
+        lb_create_flow.add(a10_database_tasks.GetFlavorData(
+            rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
+            provides=constants.FLAVOR_DATA))
         lb_create_flow.add(
             self.get_post_lb_vthunder_association_flow(
                 post_amp_prefix, load_balancer_id, topology, vthunder,
                 mark_active=(not listeners)))
-        lb_create_flow.add(a10_database_tasks.GetFlavorData(
-            rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
-            provides=constants.FLAVOR_DATA))
         lb_create_flow.add(a10_database_tasks.CountLoadbalancersWithFlavor(
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER),
             provides=a10constants.LB_COUNT_FLAVOR))
@@ -195,7 +195,8 @@ class LoadBalancerFlows(object):
         post_create_lb_flow.add(database_tasks.UpdateLoadbalancerInDB(
             requires=[constants.LOADBALANCER, constants.UPDATE_DICT]))
 
-        post_create_lb_flow.add(self.handle_vrid_for_loadbalancer_subflow())
+        if CONF.a10_global.handle_vrid:
+            post_create_lb_flow.add(self.handle_vrid_for_loadbalancer_subflow())
 
         if mark_active:
             post_create_lb_flow.add(database_tasks.MarkLBActiveInDB(
@@ -289,7 +290,8 @@ class LoadBalancerFlows(object):
             a10_database_tasks.CountLoadbalancersInProjectBySubnet(
                 requires=[constants.SUBNET, a10constants.PARTITION_PROJECT_LIST],
                 provides=a10constants.LB_COUNT_SUBNET))
-        delete_LB_flow.add(self.get_delete_lb_vrid_subflow(deleteCompute))
+        if CONF.a10_global.handle_vrid:
+            delete_LB_flow.add(self.get_delete_lb_vrid_subflow(deleteCompute))
         delete_LB_flow.add(a10_network_tasks.DeallocateVIP(
             requires=[constants.LOADBALANCER, a10constants.LB_COUNT_SUBNET]))
         delete_LB_flow.add(virtual_server_tasks.DeleteVirtualServerTask(
@@ -548,7 +550,23 @@ class LoadBalancerFlows(object):
         # update_LB_flow.add(amphora_driver_tasks.ListenersUpdate(
         #    requires=[constants.LOADBALANCER, constants.LISTENERS]))
         # post_create_lb_flow.add(handle_vrid_for_loadbalancer_subflow())
-        update_LB_flow.add(self.handle_vrid_for_loadbalancer_subflow())
+        if CONF.a10_global.handle_vrid:
+            update_LB_flow.add(self.handle_vrid_for_loadbalancer_subflow())
+        update_LB_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
+            requires=constants.LOADBALANCER,
+            provides=constants.AMPHORA))
+        update_LB_flow.add(a10_database_tasks.GetLoadbalancersInProjectBySubnet(
+            requires=[constants.SUBNET, a10constants.PARTITION_PROJECT_LIST],
+            provides=a10constants.LOADBALANCERS_LIST))
+        update_LB_flow.add(a10_database_tasks.CheckForL2DSRFlavor(
+            rebind={a10constants.LB_RESOURCE: a10constants.LOADBALANCERS_LIST},
+            provides=a10constants.L2DSR_FLAVOR))
+        update_LB_flow.add(a10_database_tasks.CountMembersInProjectBySubnet(
+            requires=[constants.SUBNET, a10constants.PARTITION_PROJECT_LIST],
+            provides=a10constants.MEMBER_COUNT))
+        update_LB_flow.add(vthunder_tasks.UpdateL2DSR(
+            requires=(constants.SUBNET, constants.AMPHORA,
+                      a10constants.MEMBER_COUNT, a10constants.L2DSR_FLAVOR)))
         update_LB_flow.add(a10_database_tasks.GetFlavorData(
             rebind={a10constants.LB_RESOURCE: constants.LOADBALANCER},
             provides=constants.FLAVOR_DATA))
@@ -603,7 +621,8 @@ class LoadBalancerFlows(object):
             provides=a10constants.VTHUNDER))
         update_LB_flow.add(network_tasks.ApplyQos(
             requires=(constants.LOADBALANCER, constants.UPDATE_DICT)))
-        update_LB_flow.add(self.handle_vrid_for_loadbalancer_subflow())
+        if CONF.a10_global.handle_vrid:
+            update_LB_flow.add(self.handle_vrid_for_loadbalancer_subflow())
 
         update_LB_flow.add(virtual_server_tasks.UpdateVirtualServerTask(
             requires=(constants.LOADBALANCER, a10constants.VTHUNDER,
@@ -732,7 +751,8 @@ class LoadBalancerFlows(object):
             a10_database_tasks.CountLoadbalancersOnThunderBySubnet(
                 requires=[a10constants.VTHUNDER, constants.SUBNET, a10constants.USE_DEVICE_FLAVOR],
                 provides=a10constants.LB_COUNT_THUNDER))
-        delete_LB_flow.add(self.get_delete_rack_lb_vrid_subflow())
+        if CONF.a10_global.handle_vrid:
+            delete_LB_flow.add(self.get_delete_rack_lb_vrid_subflow())
         delete_LB_flow.add(a10_network_tasks.DeallocateVIP(
             requires=[constants.LOADBALANCER, a10constants.LB_COUNT_SUBNET]))
         delete_LB_flow.add(virtual_server_tasks.DeleteVirtualServerTask(
@@ -799,7 +819,8 @@ class LoadBalancerFlows(object):
             post_create_lb_flow.add(vthunder_tasks.TagInterfaceForLB(
                 requires=[constants.LOADBALANCER,
                           a10constants.VTHUNDER]))
-        post_create_lb_flow.add(self.handle_vrid_for_loadbalancer_subflow())
+        if CONF.a10_global.handle_vrid:
+            post_create_lb_flow.add(self.handle_vrid_for_loadbalancer_subflow())
         if mark_active:
             post_create_lb_flow.add(database_tasks.MarkLBActiveInDB(
                 name=sf_name + '-' + constants.MARK_LB_ACTIVE_INDB,
