@@ -48,9 +48,10 @@ class MemberFlows(object):
 
         create_member_flow.add(database_tasks.MarkMemberPendingCreateInDB(
             requires=constants.MEMBER))
-        create_member_flow.add(a10_network_tasks.ValidateSubnet(
-            name='validate-subnet',
-            requires=constants.MEMBER))
+        if CONF.a10_global.validate_subnet:
+            create_member_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet',
+                requires=constants.MEMBER))
         create_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -159,7 +160,8 @@ class MemberFlows(object):
                         constants.ADDED_PORTS,
                         constants.LOADBALANCER,
                         a10constants.VTHUNDER]))
-        create_member_flow.add(self.handle_vrid_for_member_subflow())
+        if CONF.a10_global.handle_vrid:
+            create_member_flow.add(self.handle_vrid_for_member_subflow())
         create_member_flow.add(a10_database_tasks.CountMembersWithIP(
             requires=constants.MEMBER, provides=a10constants.MEMBER_COUNT_IP
         ))
@@ -286,7 +288,8 @@ class MemberFlows(object):
                     constants.POOL,
                     a10constants.MEMBER_COUNT_IP,
                     a10constants.MEMBER_COUNT_IP_PORT_PROTOCOL)))
-        delete_member_flow.add(self.get_delete_member_vrid_subflow())
+        if CONF.a10_global.handle_vrid:
+            delete_member_flow.add(self.get_delete_member_vrid_subflow())
         delete_member_flow.add(database_tasks.DeleteMemberInDB(
             requires=constants.MEMBER))
         delete_member_flow.add(database_tasks.DecrementMemberQuota(
@@ -381,7 +384,8 @@ class MemberFlows(object):
                         constants.MEMBER,
                         a10constants.VTHUNDER]))
         # Handle VRID setting
-        delete_member_flow.add(self.get_delete_member_vrid_subflow())
+        if CONF.a10_global.handle_vrid:
+            delete_member_flow.add(self.get_delete_member_vrid_subflow())
         delete_member_flow.add(database_tasks.DeleteMemberInDB(
             requires=constants.MEMBER))
         delete_member_flow.add(database_tasks.DecrementMemberQuota(
@@ -609,9 +613,10 @@ class MemberFlows(object):
 
         update_member_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
             requires=constants.MEMBER))
-        update_member_flow.add(a10_network_tasks.ValidateSubnet(
-            name='validate-subnet',
-            requires=constants.MEMBER))
+        if CONF.a10_global.validate_subnet:
+            update_member_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet',
+                requires=constants.MEMBER))
         update_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -620,7 +625,8 @@ class MemberFlows(object):
                 name=a10constants.GET_MASTER_VTHUNDER,
                 requires=a10constants.VTHUNDER,
                 provides=a10constants.VTHUNDER))
-        update_member_flow.add(self.handle_vrid_for_member_subflow())
+        if CONF.a10_global.handle_vrid:
+            update_member_flow.add(self.handle_vrid_for_member_subflow())
         update_member_flow.add(database_tasks.GetAmphoraeFromLoadbalancer(
             requires=constants.LOADBALANCER,
             provides=constants.AMPHORA))
@@ -672,9 +678,10 @@ class MemberFlows(object):
                       constants.POOL]))
         update_member_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
             requires=constants.MEMBER))
-        update_member_flow.add(a10_network_tasks.ValidateSubnet(
-            name='validate-subnet',
-            requires=constants.MEMBER))
+        if CONF.a10_global.validate_subnet:
+            update_member_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet',
+                requires=constants.MEMBER))
         update_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -695,7 +702,8 @@ class MemberFlows(object):
             provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
 
         # Handle VRID settings
-        update_member_flow.add(self.handle_vrid_for_member_subflow())
+        if CONF.a10_global.handle_vrid:
+            update_member_flow.add(self.handle_vrid_for_member_subflow())
         update_member_flow.add(server_tasks.MemberUpdate(
             requires=(constants.MEMBER, a10constants.VTHUNDER,
                       constants.POOL, constants.FLAVOR)))
@@ -731,9 +739,10 @@ class MemberFlows(object):
                       constants.POOL]))
         create_member_flow.add(database_tasks.MarkMemberPendingCreateInDB(
             requires=constants.MEMBER))
-        create_member_flow.add(a10_network_tasks.ValidateSubnet(
-            name='validate-subnet',
-            requires=constants.MEMBER))
+        if CONF.a10_global.validate_subnet:
+            create_member_flow.add(a10_network_tasks.ValidateSubnet(
+                name='validate-subnet',
+                requires=constants.MEMBER))
         create_member_flow.add(a10_database_tasks.GetVThunderByLoadBalancer(
             requires=constants.LOADBALANCER,
             provides=a10constants.VTHUNDER))
@@ -750,7 +759,8 @@ class MemberFlows(object):
                       a10constants.DEVICE_CONFIG_DICT),
             rebind={constants.FLAVOR_DATA: constants.FLAVOR},
             provides=(a10constants.VTHUNDER_CONFIG, a10constants.USE_DEVICE_FLAVOR)))
-        create_member_flow.add(self.handle_vrid_for_member_subflow())
+        if CONF.a10_global.handle_vrid:
+            create_member_flow.add(self.handle_vrid_for_member_subflow())
         if CONF.a10_global.network_type == 'vlan':
             create_member_flow.add(vthunder_tasks.TagInterfaceForMember(
                 requires=[constants.MEMBER,
@@ -884,8 +894,9 @@ class MemberFlows(object):
                 inject={constants.MEMBER: m},
                 name='{flow}-{id}'.format(
                     id=m.id, flow=constants.DECREMENT_MEMBER_QUOTA_FLOW)))
-        batch_update_members_flow.add(
-            self.get_delete_member_vrid_internal_subflow(constants.POOL, old_members))
+        if CONF.a10_global.handle_vrid:
+            batch_update_members_flow.add(
+                self.get_delete_member_vrid_internal_subflow(constants.POOL, old_members))
 
         # for creation of members
         batch_update_members_flow.add(lifecycle_tasks.MembersToErrorOnRevertTask(
@@ -896,9 +907,10 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingCreateInDB(
                 name='mark-member-pending-create-in-db-' + m.id,
                 inject={constants.MEMBER: m}))
-            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet' + m.id,
-                inject={constants.MEMBER: m}))
+            if CONF.a10_global.validate_subnet:
+                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                    name='validate-subnet' + m.id,
+                    inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_database_tasks.CountMembersWithIP(
                 name='count-member-with-ip-' + m.id,
                 inject={constants.MEMBER: m},
@@ -926,9 +938,10 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
                 inject={constants.MEMBER: m},
                 name='mark-member-pending-update-in-db-' + m.id))
-            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet' + m.id,
-                inject={constants.MEMBER: m}))
+            if CONF.a10_global.validate_subnet:
+                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                    name='validate-subnet' + m.id,
+                    inject={constants.MEMBER: m}))
             batch_update_members_flow.add(server_tasks.MemberUpdate(
                 name='member-update-' + m.id,
                 inject={constants.MEMBER: m},
@@ -945,8 +958,9 @@ class MemberFlows(object):
         existing_members = [m[0] for m in updated_members]
         pool_members = new_members + existing_members
         if pool_members:
-            batch_update_members_flow.add(
-                self.get_handle_member_vrid_internal_subflow(pool_members))
+            if CONF.a10_global.handle_vrid:
+                batch_update_members_flow.add(
+                    self.get_handle_member_vrid_internal_subflow(pool_members))
             if CONF.a10_global.network_type == 'vlan':
                 batch_update_members_flow.add(vthunder_tasks.TagInterfaceForMember(
                     name='update_tagged_interface_for_members',
@@ -1064,8 +1078,9 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.DecrementMemberQuota(
                 name='decrement-member-quota' + m.id,
                 inject={constants.MEMBER: m}))
-        batch_update_members_flow.add(
-            self.get_delete_member_vrid_internal_subflow(constants.POOL, old_members))
+        if CONF.a10_global.handle_vrid:
+            batch_update_members_flow.add(
+                self.get_delete_member_vrid_internal_subflow(constants.POOL, old_members))
 
         # for creation of members
         batch_update_members_flow.add(lifecycle_tasks.MembersToErrorOnRevertTask(
@@ -1076,9 +1091,10 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingCreateInDB(
                 name='mark-member-pending-create-in-DB' + m.id,
                 inject={constants.MEMBER: m}))
-            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet' + m.id,
-                inject={constants.MEMBER: m}))
+            if CONF.a10_global.validate_subnet:
+                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                    name='validate-subnet' + m.id,
+                    inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_database_tasks.CountMembersWithIP(
                 name='count-members-with-ip' + m.id,
                 inject={constants.MEMBER: m},
@@ -1108,9 +1124,10 @@ class MemberFlows(object):
             batch_update_members_flow.add(database_tasks.MarkMemberPendingUpdateInDB(
                 inject={constants.MEMBER: m},
                 name='mark-member-pending-update-in-db-' + m.id))
-            batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
-                name='validate-subnet' + m.id,
-                inject={constants.MEMBER: m}))
+            if CONF.a10_global.validate_subnet:
+                batch_update_members_flow.add(a10_network_tasks.ValidateSubnet(
+                    name='validate-subnet' + m.id,
+                    inject={constants.MEMBER: m}))
             batch_update_members_flow.add(a10_network_tasks.GetLBResourceSubnet(
                 name='{flow}-{id}'.format(
                     id=m.id, flow=a10constants.GET_LB_RESOURCE_SUBNET),
@@ -1230,8 +1247,9 @@ class MemberFlows(object):
         existing_members = [m[0] for m in updated_members]
         pool_members = new_members + existing_members
         if pool_members:
-            batch_update_members_flow.add(
-                self.get_handle_member_vrid_internal_subflow(pool_members))
+            if CONF.a10_global.handle_vrid:
+                batch_update_members_flow.add(
+                    self.get_handle_member_vrid_internal_subflow(pool_members))
         for m in new_members:
             batch_update_members_flow.add(self.get_batch_update_member_snat_pool_subflow(m))
 
