@@ -19,6 +19,7 @@ from taskflow import task
 
 from a10_octavia.common import openstack_mappings
 from a10_octavia.controller.worker.tasks.decorators import axapi_client_decorator
+from a10_octavia.controller.worker.tasks.decorators import axapi_client_decorator_for_revert
 from a10_octavia.controller.worker.tasks.policy import PolicyUtil
 from a10_octavia.controller.worker.tasks import utils
 
@@ -35,7 +36,7 @@ class L7PolicyParent(object):
         size = len(script.encode('utf-8'))
         listener = listeners[0]
         c_pers, s_pers = utils.get_sess_pers_templates(listener.default_pool)
-        kargs = {}
+        kwargs = {}
         listener.protocol = openstack_mappings.virtual_port_protocol(self.axapi_client,
                                                                      listener.protocol)
         try:
@@ -60,14 +61,14 @@ class L7PolicyParent(object):
             aflex_scripts.append({"aflex": filename})
         else:
             aflex_scripts = [{"aflex": filename}]
-        kargs["aflex_scripts"] = aflex_scripts
+        kwargs["aflex_scripts"] = aflex_scripts
 
         try:
             self.axapi_client.slb.virtual_server.vport.update(
                 listener.load_balancer_id, listener.id,
                 listener.protocol, listener.protocol_port,
                 listener.default_pool_id, s_pers,
-                c_pers, 1, **kargs)
+                c_pers, 1, **kwargs)
             LOG.debug(
                 "Successfully associated l7policy %s to listener %s",
                 l7policy.id,
@@ -87,7 +88,7 @@ class CreateL7Policy(L7PolicyParent, task.Task):
     def execute(self, l7policy, listeners, vthunder):
         self.set(l7policy, listeners)
 
-    @axapi_client_decorator
+    @axapi_client_decorator_for_revert
     def revert(self, l7policy, listeners, vthunder, *args, **kwargs):
         try:
             self.axapi_client.slb.aflex_policy.delete(l7policy.id)
@@ -116,13 +117,17 @@ class DeleteL7Policy(task.Task):
         listener = l7policy.listener
         c_pers, s_pers = utils.get_sess_pers_templates(
             listener.default_pool)
-        kargs = {}
-        listener.protocol = openstack_mappings.virtual_port_protocol(self.axapi_client,
-                                                                     listener.protocol)
+        kwargs = {}
+        snat_pool = None
+        if not (listener.protocol).islower():
+            listener.protocol = openstack_mappings.virtual_port_protocol(
+                self.axapi_client, listener.protocol)
         try:
             get_listener = self.axapi_client.slb.virtual_server.vport.get(
                 listener.load_balancer_id, listener.id,
                 listener.protocol, listener.protocol_port)
+            if get_listener and 'port' in get_listener and 'pool' in get_listener['port']:
+                snat_pool = get_listener['port']['pool']
             LOG.debug("Successfully fetched listener %s for l7policy %s", listener.id, l7policy.id)
         except (acos_errors.ACOSException, exceptions.ConnectionError) as e:
             LOG.exception("Failed to get listener %s for l7policy: %s", listener.id, l7policy.id)
@@ -134,14 +139,15 @@ class DeleteL7Policy(task.Task):
             for aflex in aflex_scripts:
                 if aflex['aflex'] != l7policy.id:
                     new_aflex_scripts.append(aflex)
-        kargs["aflex_scripts"] = new_aflex_scripts
+        kwargs["aflex_scripts"] = new_aflex_scripts
 
         try:
             self.axapi_client.slb.virtual_server.vport.replace(
                 listener.load_balancer_id, listener.id,
                 listener.protocol, listener.protocol_port,
                 listener.default_pool_id,
-                s_pers, c_pers, 1, **kargs)
+                s_pers, c_pers, 1,
+                source_nat_pool=snat_pool, **kwargs)
             LOG.debug(
                 "Successfully dissociated l7policy %s from listener %s",
                 l7policy.id,
