@@ -170,14 +170,45 @@ class DeleteL2DSR(VThunderBaseTask):
                                 subnet.network_id, amp)
 
 
+class UpdateL2DSR(VThunderBaseTask):
+    """Task to update wildcat address in allowed_address_pair for L2DSR"""
+
+    def execute(self, subnet, amphora, member_count, l2dsr_flavor):
+        if CONF.vthunder.l2dsr_support:
+            for amp in amphora:
+                self.network_driver.allow_use_any_source_ip_on_egress(subnet.network_id, amp)
+        else:
+            if not l2dsr_flavor:
+                if (CONF.vthunder.slb_no_snat_support and member_count < 1) or \
+                        (not CONF.vthunder.slb_no_snat_support):
+                    for amp in amphora:
+                        self.network_driver.remove_any_source_ip_on_egress(subnet.network_id, amp)
+
+
 class AllowLoadbalancerForwardWithAnySource(VThunderBaseTask):
     """Task to add wildcat address in allowed_address_pair to allow any SNAT"""
 
     def execute(self, member, amphora):
-        subnet = self.network_driver.get_subnet(member.subnet_id)
+        if member.subnet_id:
+            subnet = self.network_driver.get_subnet(member.subnet_id)
+            if CONF.vthunder.slb_no_snat_support:
+                for amp in amphora:
+                    self.network_driver.allow_use_any_source_ip_on_egress(subnet.network_id, amp)
+
+
+class UpdateLoadbalancerForwardWithAnySource(VThunderBaseTask):
+    """Task to update wildcat address in allowed_address_pair to allow any SNAT"""
+
+    def execute(self, subnet, amphora, lb_count_subnet, l2dsr_flavor):
         if CONF.vthunder.slb_no_snat_support:
             for amp in amphora:
                 self.network_driver.allow_use_any_source_ip_on_egress(subnet.network_id, amp)
+        else:
+            if not l2dsr_flavor:
+                if (CONF.vthunder.l2dsr_support and lb_count_subnet < 1) or \
+                        not CONF.vthunder.l2dsr_support:
+                    for amp in amphora:
+                        self.network_driver.remove_any_source_ip_on_egress(subnet.network_id, amp)
 
 
 class AmphoraePostMemberNetworkPlug(VThunderBaseTask):
@@ -823,42 +854,49 @@ class TagInterfaceForMember(TagInterfaceBaseTask):
 
     @axapi_client_decorator
     def execute(self, member, vthunder):
-        if not member.subnet_id:
-            LOG.warning("Subnet id argument was not specified during "
-                        "issuance of create command/API call for member %s. "
-                        "Skipping TagInterfaceForMember task", member.id)
-            return
-        try:
-            vlan_id = self.get_vlan_id(member.subnet_id, False)
-            self.tag_interfaces(vthunder, vlan_id)
-            LOG.debug("Successfully tagged interface with VLAN id %s for member %s",
-                      str(vlan_id), member.id)
-        except (acos_errors.ACOSException, req_exceptions.ConnectionError) as e:
-            LOG.exception("Failed to tag interface with VLAN id %s for member %s",
-                          str(vlan_id), member.id)
-            raise e
+        member_list = member if isinstance(member, list) else [member]
+        subnet_list = []
+        for member in member_list:
+            if member.subnet_id not in subnet_list:
+                if not member.subnet_id:
+                    LOG.warning("Subnet id argument was not specified during "
+                                "issuance of create command/API call for member %s. "
+                                "Skipping TagInterfaceForMember task", member.id)
+                    continue
+                try:
+                    vlan_id = self.get_vlan_id(member.subnet_id, False)
+                    self.tag_interfaces(vthunder, vlan_id)
+                    subnet_list.append(member.subnet_id)
+                    LOG.debug("Successfully tagged interface with VLAN id %s for member %s",
+                              str(vlan_id), member.id)
+                except (acos_errors.ACOSException, req_exceptions.ConnectionError) as e:
+                    LOG.exception("Failed to tag interface with VLAN id %s for member %s",
+                                  str(vlan_id), member.id)
+                    raise e
 
     @axapi_client_decorator_for_revert
     def revert(self, member, vthunder, *args, **kwargs):
-        if not member.subnet_id:
-            LOG.warning("Subnet id argument was not specified during "
-                        "issuance of create command/API call for member %s. "
-                        "Skipping TagInterfaceForMember task", member.id)
-            return
-        try:
-            if vthunder and vthunder.device_network_map:
-                vlan_id = self.get_vlan_id(member.subnet_id, False)
-                if self.is_vlan_deletable():
-                    LOG.warning("Reverting tag interface for member with VLAN id %s", vlan_id)
-                    master_device_id = vthunder.device_network_map[0].vcs_device_id
-                    for device_obj in vthunder.device_network_map:
-                        self.delete_device_vlan(vlan_id, member.subnet_id, vthunder,
-                                                device_id=device_obj.vcs_device_id,
-                                                master_device_id=master_device_id)
-        except req_exceptions.ConnectionError:
-            LOG.exception("Failed to connect A10 Thunder device: %s", vthunder.ip_address)
-        except Exception as e:
-            LOG.exception("Failed to delete VLAN %s due to %s", str(vlan_id), str(e))
+        member_list = member if isinstance(member, list) else [member]
+        for member in member_list:
+            if not member.subnet_id:
+                LOG.warning("Subnet id argument was not specified during "
+                            "issuance of create command/API call for member %s. "
+                            "Skipping TagInterfaceForMember task", member.id)
+                continue
+            try:
+                if vthunder and vthunder.device_network_map:
+                    vlan_id = self.get_vlan_id(member.subnet_id, False)
+                    if self.is_vlan_deletable():
+                        LOG.warning("Reverting tag interface for member with VLAN id %s", vlan_id)
+                        master_device_id = vthunder.device_network_map[0].vcs_device_id
+                        for device_obj in vthunder.device_network_map:
+                            self.delete_device_vlan(vlan_id, member.subnet_id, vthunder,
+                                                    device_id=device_obj.vcs_device_id,
+                                                    master_device_id=master_device_id)
+            except req_exceptions.ConnectionError:
+                LOG.exception("Failed to connect A10 Thunder device: %s", vthunder.ip_address)
+            except Exception as e:
+                LOG.exception("Failed to delete VLAN %s due to %s", str(vlan_id), str(e))
 
 
 class DeleteInterfaceTagIfNotInUseForLB(TagInterfaceBaseTask):
