@@ -33,6 +33,25 @@ RACK_DEVICE = {
     "interface_vlan_map": {"1": {"11": {"use_dhcp": True}, "12": {"use_dhcp": True}}}
 }
 
+RACK_DEVICE_LIST = {
+    "project-rack-vthunder": {
+        "project_id": "project-rack-vthunder",
+        "ip_address": "10.0.0.1",
+        "device_name": "rack_vthunder",
+        "username": "abc",
+        "password": "abc",
+        "interface_vlan_map": {"1": {"11": {"use_dhcp": True}, "12": {"use_dhcp": True}}}
+    },
+    "[dev]rack_vthunder": {
+        "project_id": "project-rack-vthunder",
+        "ip_address": "10.0.0.1",
+        "device_name": "rack_vthunder",
+        "username": "abc",
+        "password": "abc",
+        "interface_vlan_map": {"1": {"11": {"use_dhcp": True}, "12": {"use_dhcp": True}}}
+    }
+}
+
 
 class TestMemberFlows(base.TestCase):
     def setUp(self):
@@ -48,7 +67,7 @@ class TestMemberFlows(base.TestCase):
         self.conf.register_opts(config_options.A10_GLOBAL_OPTS,
                                 group=a10constants.A10_GLOBAL_CONF_SECTION)
         self.conf.config(group=a10constants.A10_GLOBAL_CONF_SECTION, network_type='vlan')
-        create_flow = self.flows.get_rack_vthunder_create_member_flow()
+        create_flow = self.flows.get_rack_vthunder_create_member_flow(RACK_DEVICE, RACK_DEVICE_LIST)
         self.assertIsInstance(create_flow, flow.Flow)
 
     def test_delete_member_rack_vthunder_vlan_flow(self):
