@@ -32,6 +32,7 @@ from a10_octavia.tests.common import a10constants
 from a10_octavia.tests.unit import base
 
 MEMBER = o_data_models.Member(subnet_id=a10constants.MOCK_SUBNET_ID)
+POOL = o_data_models.Pool()
 VTHUNDER = data_models.VThunder()
 SUBNET = o_net_data_models.Subnet()
 PORT = o_net_data_models.Port()
@@ -124,6 +125,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
             self, mock_patched_ip, mock_floating_ip):
         member = copy.deepcopy(MEMBER)
         member.subnet_id = SUBNET_1.id
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         subnet = copy.deepcopy(SUBNET_1)
         subnet.cidr = a10constants.MOCK_SUBNET_CIDR
         vthunder_config = copy.deepcopy(HW_THUNDER)
@@ -136,7 +139,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.network_driver_mock.allocate_vrid_fip.return_value = port
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_called_with(
             mock.ANY, None, mock.ANY,
             fixed_ip=a10constants.MOCK_VRID_FLOATING_IP_1)
@@ -150,6 +153,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
             self, mock_patched_ip):
         member = copy.deepcopy(MEMBER)
         member.subnet_id = SUBNET_1.id
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         subnet = copy.deepcopy(SUBNET_1)
         subnet.cidr = a10constants.MOCK_SUBNET_CIDR
         vthunder_config = copy.deepcopy(HW_THUNDER2)
@@ -162,7 +167,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [], subnet,
+        mock_network_task.execute(vthunder, member, [], subnet,
                                   vthunder_config, use_device_flavor=True)
         mock_network_task.axapi_client.get_vrid_floating_ip_for_project.assert_not_called()
         self.client_mock.vrrpa.update.assert_called_with(
@@ -185,6 +190,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         port.fixed_ips.append(MockIP(a10constants.MOCK_VRID_FLOATING_IP_1))
         vthunder = copy.deepcopy(VTHUNDER)
         vthunder.partition_name = 'partition_1'
+        vthunder.ip_address = '10.0.0.1'
         mock_network_task = a10_network_tasks.HandleVRIDFloatingIP()
         mock_network_task.axapi_client = self.client_mock
         self.network_driver_mock.get_subnet.return_value = subnet
@@ -210,6 +216,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
             self, get_floating_ip, check_subnet):
         member = copy.deepcopy(MEMBER)
         member.subnet_id = SUBNET_1.id
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         subnet = copy.deepcopy(SUBNET_1)
         subnet.cidr = a10constants.MOCK_SUBNET_CIDR
         vthunder_config = copy.deepcopy(HW_THUNDER)
@@ -222,7 +230,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [VRID_1], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [VRID_1], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_called_with(
             mock.ANY, None, None, fixed_ip=None)
         self.client_mock.vrrpa.update.assert_called_with(
@@ -246,6 +254,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         port.fixed_ips.append(MockIP(a10constants.MOCK_VRID_FLOATING_IP_1))
         vthunder = copy.deepcopy(VTHUNDER)
         vthunder.partition_name = 'partition_1'
+        vthunder.ip_address = '10.0.0.1'
         mock_network_task = a10_network_tasks.HandleVRIDFloatingIP()
         mock_network_task.axapi_client = self.client_mock
         self.network_driver_mock.get_subnet.return_value = subnet
@@ -287,6 +296,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         vrid = copy.deepcopy(VRID_1)
         vrid.vrid_floating_ip = a10constants.MOCK_VRID_FLOATING_IP_1
         vrid.vrid = VRID_VALUE
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         member = copy.deepcopy(MEMBER)
         member.subnet_id = a10constants.MOCK_SUBNET_ID
         subnet = copy.deepcopy(SUBNET_1)
@@ -298,7 +309,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         mock_network_task.axapi_client = self.client_mock
         self.network_driver_mock.get_subnet.return_value = subnet
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
-        mock_network_task.execute(VTHUNDER, member, [vrid], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [vrid], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_not_called()
         self.client_mock.vrrpa.update.assert_not_called()
 
@@ -310,6 +321,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
     def test_HandleVRIDFloatingIP_replace_floating_ip_in_shared_partition_with_static_ip(
             self, mock_utils, mock_patched_ip, get_floating_ip):
         vrid = copy.deepcopy(VRID_1)
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         vrid.vrid_floating_ip = a10constants.MOCK_VRID_FLOATING_IP_1
         vrid.vrid = VRID_VALUE
         vrid.vrid_port_id = a10constants.MOCK_VRRP_PORT_ID
@@ -327,7 +340,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [vrid], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [vrid], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_called_with(
             vrid, subnet.network_id, mock.ANY,
             fixed_ip=a10constants.MOCK_VRID_FLOATING_IP_2)
@@ -356,6 +369,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         vthunder_config = copy.deepcopy(HW_THUNDER)
         port.fixed_ips.append(MockIP(a10constants.MOCK_VRID_FLOATING_IP_2))
         vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         vthunder.partition_name = 'partition_1'
         mock_network_task = a10_network_tasks.HandleVRIDFloatingIP()
         mock_network_task.axapi_client = self.client_mock
@@ -380,6 +394,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
     def test_HandleVRIDFloatingIP_noop_given_same_subnet_with_conf_fip_set_to_dhcp(
             self, get_floating_ip):
         vrid = copy.deepcopy(VRID_1)
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         vrid.vrid_floating_ip = a10constants.MOCK_VRID_FLOATING_IP_1
         vrid.vrid = VRID_VALUE
         vrid.vrid_port_id = a10constants.MOCK_VRRP_PORT_ID
@@ -392,7 +408,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         mock_network_task.axapi_client = self.client_mock
         self.network_driver_mock.get_subnet.return_value = subnet
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
-        fip_port = mock_network_task.execute(VTHUNDER, member, [vrid], subnet, vthunder_config)
+        fip_port = mock_network_task.execute(vthunder, member, [vrid], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_not_called()
         self.network_driver_mock.delete_port.assert_not_called()
         self.assertEqual(fip_port, [vrid])
@@ -407,6 +423,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
     def test_HandleVRIDFloatingIP_replace_floating_ip_diff_subnet_in_shared_part_conf_fip_set_dhcp(
             self, mock_utils, get_floating_ip, check_subnet):
         vrid = copy.deepcopy(VRID_1)
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         vrid.vrid_floating_ip = a10constants.MOCK_VRID_FLOATING_IP_1
         vrid.vrid = VRID_VALUE
         vrid.vrid_port_id = a10constants.MOCK_VRRP_PORT_ID
@@ -425,7 +443,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [vrid], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [vrid], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_called_with(
             vrid, subnet.network_id, mock.ANY, fixed_ip=None)
         self.client_mock.vrrpa.update.assert_called_with(
@@ -454,6 +472,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         port.fixed_ips.append(MockIP(a10constants.MOCK_VRID_FLOATING_IP_1))
         vthunder = copy.deepcopy(VTHUNDER)
         vthunder.partition_name = 'partition_1'
+        vthunder.ip_address = '10.0.0.1'
         mock_network_task = a10_network_tasks.HandleVRIDFloatingIP()
         mock_network_task.axapi_client = self.client_mock
         self.network_driver_mock.get_subnet.return_value = subnet
@@ -477,6 +496,8 @@ class TestNetworkTasks(base.BaseTaskTestCase):
             self, get_floating_ip, mock_utils):
         member = copy.deepcopy(MEMBER)
         member.subnet_id = a10constants.MOCK_SUBNET_ID
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
         subnet = copy.deepcopy(SUBNET_1)
         subnet.cidr = a10constants.MOCK_SUBNET_CIDR
         port = copy.deepcopy(PORT)
@@ -490,7 +511,7 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
         self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
                          vrid=VRID_VALUE)
-        mock_network_task.execute(VTHUNDER, member, [VRID_1], subnet, vthunder_config)
+        mock_network_task.execute(vthunder, member, [VRID_1], subnet, vthunder_config)
         self.network_driver_mock.allocate_vrid_fip.assert_called_with(
             mock.ANY, subnet.network_id, mock.ANY,
             fixed_ip=a10constants.MOCK_VRID_FULL_FLOATING_IP)
@@ -568,3 +589,37 @@ class TestNetworkTasks(base.BaseTaskTestCase):
         NAT_POOL.member_ref_count = 1
         mock_network_task.execute(MEMBER, NAT_FLAVOR, NAT_POOL)
         self.client_mock.delete_port.assert_called_with(NAT_POOL.port_id)
+
+    @mock.patch('a10_octavia.common.utils.get_vrid_floating_ip_for_project',
+                return_value=a10constants.MOCK_VRID_FLOATING_IP_1)
+    @mock.patch('a10_octavia.common.utils.get_patched_ip_address',
+                return_value=a10constants.MOCK_VRID_FLOATING_IP_1)
+    def test_HandleVRIDFloatingIP_create_floating_ip_for_subnet_list(
+            self, mock_patched_ip, mock_floating_ip):
+        vthunder = copy.deepcopy(VTHUNDER)
+        vthunder.ip_address = '10.0.0.1'
+        subnet = copy.deepcopy(SUBNET_1)
+        subnet.cidr = a10constants.MOCK_SUBNET_CIDR
+        vthunder_config = copy.deepcopy(HW_THUNDER)
+        port = copy.deepcopy(PORT)
+        port.fixed_ips.append(MockIP(a10constants.MOCK_VRID_FLOATING_IP_1))
+        self.client_mock.vrrpa.get.return_value = EXISTING_FIP_SHARED_PARTITION
+        mock_network_task = a10_network_tasks.HandleVRIDFloatingIP()
+        mock_network_task.axapi_client = self.client_mock
+        self.network_driver_mock.get_subnet.return_value = subnet
+        self.network_driver_mock.allocate_vrid_fip.return_value = port
+        self.conf.config(group=a10constants.A10_GLOBAL_OPTS,
+                         vrid=VRID_VALUE)
+        mock_network_task.execute(vthunder, POOL, [], [subnet], vthunder_config)
+        self.network_driver_mock.allocate_vrid_fip.assert_called_with(
+            mock.ANY, None, mock.ANY,
+            fixed_ip=a10constants.MOCK_VRID_FLOATING_IP_1)
+        self.client_mock.vrrpa.update.assert_called_with(
+            VRID_VALUE, floating_ips=[a10constants.MOCK_VRID_FLOATING_IP_1],
+            is_partition=False)
+
+    def test_get_all_resource_subnet(self):
+        mock_network_task = a10_network_tasks.GetAllResourceSubnet()
+        self.network_driver_mock.get_subnet.return_value = SUBNET_1
+        subnet = mock_network_task.execute([MEMBER])
+        self.assertEqual(subnet, [SUBNET_1])
